# MLX CTC

C++ and Metal extensions for [MLX](https://github.com/ml-explore/mlx) CTC Loss

## Library status

Library is passing initial tests and benchmarks.

However, it is still under development, and so called "alpha".

## TODO

- Add tests and benchmarks
- Optimize code more

## Credits

Thanks [pytorch source](https://github.com/pytorch/pytorch/blob/main/aten/src/ATen/native/LossCTC.cpp) for reference implementation, that used for initial CTC Loss development.
